﻿using BarcodeScanner;
using BarcodeScanner.Scanner;
using System;
using System.Collections;
using UnityEngine;
using UnityEngine.SceneManagement;
using UnityEngine.UI;
// using stateHandlerScript;

public class BarCodeScan : MonoBehaviour {

	private IScanner BarcodeScanner;
	public Text TextHeader;
	public RawImage Image;
	public AudioSource Audio;
	private float RestartTime;
	//public GameObject GlobalData;
	public string camstate;
	// public static BarCodeScan instance;

	// Disable Screen Rotation on that screen
	void Awake()
	{
		//instance=this;
		Screen.autorotateToPortrait = false;
		Screen.autorotateToPortraitUpsideDown = false;
	}

	void Start() {
		// Create a basic scanner
		BarcodeScanner = new Scanner();
		BarcodeScanner.Camera.Play();
		camstate = "scanning";
		// Display the camera texture through a RawImage
		BarcodeScanner.OnReady += (sender, arg) => {
			// Set Orientation & Texture
			Image.transform.localEulerAngles = BarcodeScanner.Camera.GetEulerAngles();
			Image.transform.localScale = BarcodeScanner.Camera.GetScale();
			Image.texture = BarcodeScanner.Camera.Texture;

			// Keep Image Aspect Ratio
			var rect = Image.GetComponent<RectTransform>();
			var newHeight = rect.sizeDelta.x * BarcodeScanner.Camera.Height / BarcodeScanner.Camera.Width;
			rect.sizeDelta = new Vector2(rect.sizeDelta.x, newHeight);

			RestartTime = Time.realtimeSinceStartup;
		};
	}

	/// <summary>
	/// Start a scan and wait for the callback (wait 1s after a scan success to avoid scanning multiple time the same element)
	/// </summary>
	private void StartScanner()
	{
		BarcodeScanner.Scan((barCodeType, barCodeValue) => {
			BarcodeScanner.Stop();
			if (TextHeader.text.Length > 250)
			{
				TextHeader.text = "";
			}
			//TextHeader.text += "SCANNED " + barCodeType + " / " + barCodeValue + "\n";
			TextHeader.text += "SCANNED\n" + barCodeValue;
			RestartTime += Time.realtimeSinceStartup + 1f;
			//GlobalData.GetComponent<GlobalControl>().ScannedCode = Int32.Parse(barCodeValue);
			GlobalControl.Instance.ScannedCode = Int64.Parse(barCodeValue);
			GlobalControl.Instance.ScannedCodeType = barCodeType;

			// Feedback
			Audio.Play();

			#if UNITY_ANDROID || UNITY_IOS
			Handheld.Vibrate();
			#endif
			camstate = "scanned";
		});
	}

	/// <summary>
	/// The Update method from unity need to be propagated
	/// </summary>
	void Update()
	{
		if (BarcodeScanner != null)
		{
			BarcodeScanner.Update();
		}

		// Check if the Scanner need to be started or restarted
		if (RestartTime != 0 && RestartTime < Time.realtimeSinceStartup && camstate != "scanned")
		{
			StartScanner();
			RestartTime = 0;
		}
	}

	#region UI Buttons

	public void ClickBack()
	{
		// Try to stop the camera before loading another scene
		if ( camstate != "scanned" ) {
		StartCoroutine(StopCamera(() => {
			SceneManager.LoadScene("ui");
			GlobalControl.Instance.state = "main";
			// state = "main";
		}));
		}
	}

	public void ClickC()
	{
		// Try to stop the camera before loading another scene
		if ( camstate == "scanned" ) {
		StartCoroutine(StopCamera(() => {
			SceneManager.LoadScene("dex");
			GlobalControl.Instance.state = "newmon";
		}));
		}
	}

	/// <summary>
	/// This coroutine is used because of a bneug with unity (http://forum.unity3d.com/threads/closing-scene-with-active-webcamtexture-crashes-on-android-solved.363566/)
	/// Trying to stop the camera in OnDestroy provoke random crash on Android
	/// </summary>
	/// <param name="callback"></param>
	/// <returns></returns>
	public IEnumerator StopCamera(Action callback)
	{
		// Stop Scanning
		Debug.Log("tää oli sit täÄ");
		Image = null;
		BarcodeScanner.Destroy();
		BarcodeScanner = null;

		// Wait a bit
		yield return new WaitForSeconds(0.1f);

		callback.Invoke();

	}

	#endregion
}
